@@ -26,7 +26,7 @@ from .large_file_storage import setup_lfs
 from .nlte import DirectAccessFile
 from .sme import MASK_VALUES
 from .synthesize import Synthesizer
-from .util import print_to_log
+from .util import print_to_log, show_progress_bars
 
 logger = logging.getLogger(__name__)
 
@@ -380,7 +380,11 @@ class SME_Solver:
                 else:
                     result[i] = [-10, 11]
             elif name[:8].lower() == "linelist":
-                result[i] = [-np.inf, np.inf]
+                if "excit" in name.lower():
+                    value = sme.linelist[int(name.split()[1])]["excit"][0]
+                    result[i] = [value - 0.005, value + 0.005]
+                else:
+                    result[i] = [-np.inf, np.inf]
             else:
                 result[i] = bounds[name]
 
@@ -434,7 +438,10 @@ class SME_Solver:
             elif param.startswith("Abund"):
                 step_sizes += [0.01]
             elif param.startswith("linelist"):
-                step_sizes += [0.02]
+                if "excit" in param:
+                    step_sizes += [0.001]
+                else:
+                    step_sizes += [0.2]
             else:
                 step_sizes += [0.001]
         step_sizes = np.asarray(step_sizes)
@@ -732,6 +739,8 @@ class SME_Solver:
                         "linelist parameter like 'linelist n gflog'"
                     )
                 self.update_linelist += [idx]
+        if self.update_linelist:
+            self.update_linelist = np.unique(self.update_linelist)
 
         # Create appropiate bounds
         if bounds is None:
@@ -786,18 +795,22 @@ class SME_Solver:
 
         # Do the heavy lifting
         if self.nparam > 0:
-            self.progressbar = tqdm(desc="Iteration", total=0)
-            self.progressbar_jacobian = tqdm(desc="Jacobian", total=len(p0))
+            self.progressbar = tqdm(
+                desc="Iteration", total=0, disable=~show_progress_bars
+            )
+            self.progressbar_jacobian = tqdm(
+                desc="Jacobian", total=len(p0), disable=~show_progress_bars
+            )
             with print_to_log():
                 res = least_squares(
                     self._residuals,
                     jac=self._jacobian,
                     x0=p0,
                     bounds=bounds,
-                    loss="cauchy",
+                    loss=sme.leastsquares_loss,
                     f_scale=self.f_scale,
-                    method="dogbox",
-                    # x_scale=step_sizes,
+                    method=sme.leastsquares_method,
+                    x_scale=sme.leastsquares_xscale,
                     # These control the tolerance, for early termination
                     # since each iteration is quite expensive
                     xtol=sme.accxt,
@@ -809,7 +822,7 @@ class SME_Solver:
                         "bounds": bounds,
                         "segments": segments,
                         "step_sizes": step_sizes,
-                        "method": "2-point",
+                        "method": sme.leastsquares_jac,
                     },
                 )
                 # The jacobian is altered by the loss function
@@ -824,7 +837,7 @@ class SME_Solver:
             logger.debug("Reduced chi square: %.3f", sme.fitresults.chisq)
             try:
                 for name, value, unc in zip(
-                    self.parameter_names, res.x, sme.fitresults.uncertainties
+                    self.parameter_names, res.x, sme.fitresults.fit_uncertainties
                 ):
                     logger.info("%s\t%.5f +- %.5g", name.ljust(10), value, unc)
                 logger.info("%s\t%s +- %s", "v_rad".ljust(10), sme.vrad, sme.vrad_unc)
